@@ -2,26 +2,30 @@
 #'
 #' `grid_subdivide()` makes the grid square codes finer.
 #'
-#' @inheritParams grid
-#' @inheritParams size
+#' @param grid A `grid` vector.
+#' @param grid_size A grid size.
 #'
 #' @return A list of `grid` vector.
 #'
 #' @export
-grid_subdivide <- function(grid, size) {
-  stopifnot(is_grid(grid))
+grid_subdivide <- function(grid, grid_size) {
+  if (!is_grid(grid)) {
+    cli_abort("{.arg grid} must be a vector with type {.cls grid}.")
+  }
 
-  size <- size_match(size)
-  ratio <- grid_size(grid) / size
+  grid_size <- grid_size_match(grid_size)
+  ratio <- grid_size(grid) / grid_size
 
-  stopifnot(ratio %% 1L == 0L)
+  if (!is_integerish(ratio)) {
+    cli_abort("{.arg grid} can't be subdivided.")
+  }
   ratio <- as.integer(ratio)
 
   n_X <- field(grid, "n_X")
   n_Y <- field(grid, "n_Y")
 
   purrr::map2(n_X, n_Y,
-              function(n_X, n_Y) {
+              \(n_X, n_Y) {
                 if (!is.na(n_X) && !is.na(n_Y)) {
                   n_X_min <- n_X * ratio
                   n_X_max <- (n_X + 1L) * ratio - 1L
@@ -31,11 +35,11 @@ grid_subdivide <- function(grid, size) {
 
                   n_XY <- tidyr::expand_grid(n_X = n_X_min:n_X_max,
                                              n_Y = n_Y_min:n_Y_max)
-                  new_grid(size = size,
+                  new_grid(grid_size = grid_size,
                            n_X = n_XY$n_X,
                            n_Y = n_XY$n_Y)
                 } else {
-                  new_grid(size = size)
+                  new_grid(grid_size = grid_size)
                 }
               })
 }
